betty.ancestry.note module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.note module

Provide the Note entity type and utilities.

final class betty.ancestry.note.Note

  Bases: `ShorthandPluginBase`, `UserFacingEntity`, `HasPrivacy`, `HasLinks`, `Entity`

  A note is a bit of textual information that can be associated with another entity.

  __init__(text: ShorthandStaticTranslations, *, id: str | None = None, entity: HasNotes & Entity | ToZeroOrOneResolver[HasNotes] | ToOneResolver[HasNotes] | None = None, privacy: Privacy | None = None, public: bool | None = None, private: bool | None = None)
  async dump_linked_data(project: Project) → DumpMapping[Dump]

    Dump this instance to JSON-LD.

  entity

    The entity the note belongs to.

  property label: Localizable

    The entity’s human-readable label.

  classmethod plugin_label_plural() → Localizable

    The human-readable entity type label, plural.

  text

    The human-readable note text.